phone_pe_pg library

Classes

AccountConstraint
AccountConstraint This class is used to specify the accounts for upi payments This is used in other payment instruments like UPI Intent
BillingAddress
BillingAddress
CardDetails
CardDetails
CardPaymentInstrument
CardPaymentInstrument
Data
Data
DeviceContext
DeviceContext
Expiry
Expiry
NetBankingPaymentInstrument
NetBankingPaymentInstrument
PaymentInstrument
PaymentInstrument
PaymentRequest
PaymentRequestModel
PaymentStatusReponse
PaymentStatusReponse
PayPagePaymentInstrument
PhonePePg
PhonePePg
SavedCardDetails
SavedCardDetails
SavedCardPaymentInstrument
SavedCardPaymentInstrument
TokenDetails
TokenDetails
TokenPaymentInstrument
TokenPaymentInstrument
UpiAppInfo
UpiCollectPaymentInstrument
UpiIntentPaymentInstrument
UpiIntentPaymentInstrument
UpiIntentPaymentInstrument
UpiQrPaymentInstrument
UpiQrPaymentInstrument
UpiTransactionResponse
UpiTransactionResponse

Enums

PaymentStatus
PaymentStatus in PaymentStatusReponse returned from the check status api
PaymentType
PaymentType This enum is used to specify the payment type This is used in PaymentInstrument
ResponsePaymentType
Payment Type from the status check api
UpiPaymentStatus
UpiPaymentStatus, this enum is used to determine the status of the transaction success - when the transaction is successful failure - when the transaction is failed pending - when the transaction is pending