PaymentStatus enum
PaymentStatus in PaymentStatusReponse returned from the check status api
Values
- success → const PaymentStatus
-
PaymentSuccess
const PaymentStatus(code: 'PAYMENT_SUCCESS', description: 'Invalid request') - badRequest → const PaymentStatus
-
BadRequest
const PaymentStatus(code: 'BAD_REQUEST', description: 'X-VERIFY header is incorrect') -
AuthorizationFailed Occurs when the X-VERIFY header is incorrect
const PaymentStatus(code: 'AUTHORIZATION_FAILED', description: 'Something went wrong. It does not indicate failed payment. The merchant needs to call Check Status API to verify the transac… - internalServerError → const PaymentStatus
-
InternalServerError
const PaymentStatus(code: 'INTERNAL_SERVER_ERROR', description: 'Payment is successful') - transactionNotFound → const PaymentStatus
-
TransactionNotFound
const PaymentStatus(code: 'TRANSACTION_NOT_FOUND', description: 'Payment failed') - paymentError → const PaymentStatus
-
PaymentError
const PaymentStatus(code: 'PAYMENT_ERROR', description: 'The transaction id is incorrect') - paymentPending → const PaymentStatus
-
PaymentPending
const PaymentStatus(code: 'PAYMENT_PENDING', description: 'Payment is pending. It does not indicate success/failed payment. The merchant needs to call Check Status API to verify the tr… - paymentDeclined → const PaymentStatus
-
PaymentDeclined
const PaymentStatus(code: 'PAYMENT_DECLINED', description: 'Payment declined by user') - timeout → const PaymentStatus
-
Payment Timedout
const PaymentStatus(code: 'TIMED_OUT', description: 'The payment failed due to the timeout.')
Properties
- code → String
-
Status code
final
- description → String
-
Status description
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PaymentStatus> - A constant List of the values in this enum, in order of their declaration.